
gfx = love.graphics
gameState = "menu"
triesLeft = 10
--
-- love functions and main vars
--

   function love.load()
      -- init some stuff :3
      buttons.init()
      words.init()
      
      -- create some fonts
      smFont = gfx.newFont() -- the default
      mdFont = gfx.newFont(15)
      lgFont = gfx.newFont(24)
      xlFont = gfx.newFont(32)
      xlMono = gfx.newFont("res/DejaVuSansMono.ttf", 32)
      lgMono = gfx.newFont("res/DejaVuSansMono.ttf", 24)
      
      -- set some properties
		gfx.setBackgroundColor(220,239,255)
		love.mouse.setVisible(false)
   end
   
   function love.draw()
      if gameState == "menu" then
      
         gfx.setFont(xlFont)
         gfx.setColor(88,170,208)
         gfx.print("Guess The Word",35,35)
         gfx.setFont(mdFont)
         gfx.print("Press \"Enter\" to start a new game.",35, 100)
         gfx.print("How to play: press the letters to make a guess,",35, 140)
         gfx.print("you get 10 wrong guesses.",35, 160)
         
      elseif gameState == "game" then
      
         buttons.draw()
         words.draw()
         drawTries()
         
      elseif gameState == "win" then
      
         words.draw()
         drawStatus()
         drawTries()
         
      elseif gameState == "fail" then
      
         words.draw()
         drawStatus()
         drawTries()
         
      end
   end
   
	function love.keypressed(key)
      if gameState == "menu" then
      
      elseif gameState == "game" then
         
         if string.find(buttons.abc,key) then
            -- check for the correct letter
            if not words.checkLetter(key) then
               triesLeft = triesLeft -1
            end
            
            -- check if the user has completed the word
            if completeWord() then
               gameState = "win"
            end
            
            -- if the player is out of moves then the game is over :(
            if triesLeft == 0 then
               gameState = "fail"
            end
            
            buttons.update(key)
         end
      end
      
      if key == "return" then
            newGame() -- starts a new game, NO MATTER WHAT :3
         end
   end
   
   function drawTries()
      gfx.setFont(lgFont)
      gfx.setColor(88,170,208)
      gfx.print("Tries Left:", 340, 120)
      gfx.setFont(xlFont)
      gfx.print(triesLeft, 380,170)
   end
   
   function drawStatus()
      gfx.setFont(lgFont)
      if gameState == "win" then
         gfx.setColor(124,175,69)
         gfx.print("You Win!", 35, 120)
      else
         gfx.setColor(230,88,160)
         gfx.print("Game Over!", 35, 120)
      end
      
      gfx.setColor(88,170,208)
      gfx.setFont(mdFont)
      gfx.print("Press \"Enter\" to start a new game.",35, 160)
   end
   
   function newGame()
      triesLeft = 10
      buttons.init()
      words.newWord()
      gameState = "game"
   end
   
   --
   -- word object and methods
   --
   
words = {} 
words.items = {}
words.selected = {}
words.word = {}
words.filler = "_"

   function words.init()
      -- load words from a file and populate words.items
      for line in love.filesystem.lines("res/words.txt") do
         table.insert(words.items,line)
      end
   end

   function words.newWord()
      words.selected = {}
      words.word = {} -- reset the user enterd word to nothing, then populate it with spaces
      
      -- select a random word from the words.items, and asign it to words.selected as an array
      holder = words.items[math.random(#words.items)]
      for x = 1, string.len(holder) do
         words.word[x] = " " -- add a space for each letter in the selected word
         words.selected[x] = string.sub(holder,x,x)
      end
   end
   
   function words.draw()
      gfx.setFont(xlMono)
      for x = 1, #words.selected do
         letterOffset = 35 + 28*(x-1) 
         gfx.setColor(88,170,208)
         gfx.print(words.filler,letterOffset,40) -- print out the underscore
         if gameState == "fail" and words.selected[x] ~= words.word[x] then
            -- if the game is over, show the player the missing letters in red
            gfx.setColor(230,88,160)
            gfx.print(words.selected[x],letterOffset,35)
         end
         gfx.setColor(124,175,69)
         gfx.print(words.word[x],letterOffset,35) -- print out any letters the user has correct
      end 
   end
   
   function words.checkLetter(key)
      rtn = false -- start off assuming that the letter is not in the string
      
      -- loop through each letter in the selected word
      for l = 1, #words.selected do
         -- if what the user pressed is in the word, add it to the "words.word" at the same index
         if words.selected[l] == key then
            words.word[l] = key
            rtn = true -- let them know we found it :D
         end   
      end
      
      -- also check if the user has already pressed that button and dont count it against them
      for x = 1, #buttons.items do
         if buttons.items[x] == key and buttons.enabled[x] == 2 then
            rtn = true
         end
      end
      
      return rtn -- return our results
   end
   
   function completeWord()
      -- check if the word has been completely done
      rtn = true -- assume true, better this way
      for x,l in ipairs(words.word) do
         if l == " " then
            rtn = false
            break -- no point in continuing
         end
      end
      
      return rtn
   end
   
   
   --
   -- buttons object and methods
   --
   
buttons = {}
buttons.items = {}
buttons.enabled = {}
buttons.color = { {88,170,208},{88,170,208,75}}
buttons.abc = "abcdefghijklmnopqrstuvwxyz"
   function buttons.init()
      -- fill the buttons.items table with the letters of the alphabet
      -- and set them to be enabled
      for x = 1, 26 do
         buttons.items[x] = string.sub(buttons.abc,x,x)
         buttons.enabled[x] = 1
      end
   end
   
   function buttons.draw()
   -- set the font
      gfx.setFont(lgMono)
      
      -- creat some vars to be used in the lloop
      a = 0
      b = 0
      spacer = 35
      offsetX = 35
      offsetY = 120
      
      -- loop through each letter and display it
      for x = 1, 26 do
         -- if the button has already been pressed change the color to a more transparent one
         gfx.setColor(buttons.color[buttons.enabled[x]])
         gfx.print(string.upper(buttons.items[x]),offsetX+ a*spacer,offsetY+ b*spacer)
         
         -- each set of 8 drop the letters down
         a = a + 1
         if a == 8 then
            a = 0 -- set the counter back to 0
            b = b + 1 -- increment the row
         end
      end
   end
   
   function buttons.update(key)
      for x = 1, 26 do -- loop through all the letters
         -- if the button is in the list, set it to be pressed
         if buttons.items[x] == key then buttons.enabled[x] = 2 end
      end
   end
   